@@ -41,16 +41,17 @@
           operations on files.
 */
 
-#define NAUTILUS_TYPE_DIRECTORY \
-	(nautilus_directory_get_type ())
+#define NAUTILUS_TYPE_DIRECTORY nautilus_directory_get_type()
 #define NAUTILUS_DIRECTORY(obj) \
-	(GTK_CHECK_CAST ((obj), NAUTILUS_TYPE_DIRECTORY, NautilusDirectory))
+  (G_TYPE_CHECK_INSTANCE_CAST ((obj), NAUTILUS_TYPE_DIRECTORY, NautilusDirectory))
 #define NAUTILUS_DIRECTORY_CLASS(klass) \
-	(GTK_CHECK_CLASS_CAST ((klass), NAUTILUS_TYPE_DIRECTORY, NautilusDirectoryClass))
+  (G_TYPE_CHECK_CLASS_CAST ((klass), NAUTILUS_TYPE_DIRECTORY, NautilusDirectoryClass))
 #define NAUTILUS_IS_DIRECTORY(obj) \
-	(GTK_CHECK_TYPE ((obj), NAUTILUS_TYPE_DIRECTORY))
+  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), NAUTILUS_TYPE_DIRECTORY))
 #define NAUTILUS_IS_DIRECTORY_CLASS(klass) \
-	(GTK_CHECK_CLASS_TYPE ((klass), NAUTILUS_TYPE_DIRECTORY))
+  (G_TYPE_CHECK_CLASS_TYPE ((klass), NAUTILUS_TYPE_DIRECTORY))
+#define NAUTILUS_DIRECTORY_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_CLASS ((obj), NAUTILUS_TYPE_DIRECTORY, NautilusDirectoryClass))
 
 /* NautilusFile is defined both here and in nautilus-file.h. */
 #ifndef NAUTILUS_FILE_DEFINED
@@ -117,7 +118,6 @@ typedef struct
 	void     (* file_monitor_add)    (NautilusDirectory          *directory,
 					  gconstpointer              client,
 					  gboolean                   monitor_hidden_files,
-					  gboolean                   monitor_backup_files,
 					  NautilusFileAttributes     monitor_attributes,
 					  NautilusDirectoryCallback  initial_files_callback,
 					  gpointer                   callback_data);
@@ -155,8 +155,8 @@ NautilusDirectory *nautilus_directory_get                      (GFile
 NautilusDirectory *nautilus_directory_get_by_uri               (const char                *uri);
 NautilusDirectory *nautilus_directory_get_for_file             (NautilusFile              *file);
 
-/* Covers for gtk_object_ref and gtk_object_unref that provide two conveniences:
- * 1) You don't have to cast to GtkObject *, so using these is type safe.
+/* Covers for g_object_ref and g_object_unref that provide two conveniences:
+ * 1) Using these is type safe.
  * 2) You are allowed to call these with NULL,
  */
 NautilusDirectory *nautilus_directory_ref                      (NautilusDirectory         *directory);
@@ -194,7 +194,6 @@ void               nautilus_directory_cancel_callback          (NautilusDirector
 void               nautilus_directory_file_monitor_add         (NautilusDirectory         *directory,
 								gconstpointer              client,
 								gboolean                   monitor_hidden_files,
-								gboolean                   monitor_backup_files,
 								NautilusFileAttributes     attributes,
 								NautilusDirectoryCallback  initial_files_callback,
 								gpointer                   callback_data);
@@ -223,7 +222,6 @@ gboolean           nautilus_directory_is_in_trash              (NautilusDirector
  * Only valid if directory is monitored. Used by the Trash monitor.
  */
 gboolean           nautilus_directory_is_not_empty             (NautilusDirectory         *directory);
-gboolean           nautilus_directory_file_list_length_reached (NautilusDirectory         *directory);
 
 /* Convenience functions for dealing with a list of NautilusDirectory objects that each have a ref.
  * These are just convenient names for functions that work on lists of GtkObject *.
