@@ -33,8 +33,7 @@
 #include <eel/eel-gdk-extensions.h>
 #include <eel/eel-gtk-macros.h>
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtksignal.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
 struct NautilusEntryDetails {
@@ -51,18 +50,17 @@ enum {
 };
 static guint signals[LAST_SIGNAL];
 
-static void nautilus_entry_init       (NautilusEntry      *entry);
-static void nautilus_entry_class_init (NautilusEntryClass *class);
+static void nautilus_entry_editable_init (GtkEditableInterface *iface);
 
-static GObjectClass *parent_class = NULL;
-static GtkEditableClass *parent_editable_interface = NULL;
+G_DEFINE_TYPE_WITH_CODE (NautilusEntry, nautilus_entry, GTK_TYPE_ENTRY,
+			 G_IMPLEMENT_INTERFACE (GTK_TYPE_EDITABLE,
+						nautilus_entry_editable_init));
+
+static GtkEditableInterface *parent_editable_interface = NULL;
 
 static void
 nautilus_entry_init (NautilusEntry *entry)
 {
-	GtkWidget *widget;
-
-	widget = GTK_WIDGET (entry);
 	entry->details = g_new0 (NautilusEntryDetails, 1);
 	
 	entry->details->user_edit = TRUE;
@@ -82,7 +80,7 @@ nautilus_entry_new_with_max_length (guint16 max)
 	GtkWidget *widget;
 
 	widget = gtk_widget_new (NAUTILUS_TYPE_ENTRY, NULL);
-	GTK_ENTRY (widget)->text_max_length = max;
+	gtk_entry_set_max_length (GTK_ENTRY (widget), max);
 
 	return widget;
 }
@@ -100,7 +98,7 @@ nautilus_entry_finalize (GObject *object)
 	
 	g_free (entry->details);
 
-	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
+	G_OBJECT_CLASS (nautilus_entry_parent_class)->finalize (object);
 }
 
 static gboolean
@@ -120,7 +118,7 @@ nautilus_entry_key_press (GtkWidget *widget, GdkEventKey *event)
 	}
 
 	switch (event->keyval) {
-	case GDK_Tab:
+	case GDK_KEY_Tab:
 		/* The location bar entry wants TAB to work kind of
 		 * like it does in the shell for command completion,
 		 * so if we get a tab and there's a selection, we
@@ -140,8 +138,7 @@ nautilus_entry_key_press (GtkWidget *widget, GdkEventKey *event)
 	
 	old_has = gtk_editable_get_selection_bounds (editable, NULL, NULL);
 
-	result = EEL_CALL_PARENT_WITH_RETURN_VALUE
-		(GTK_WIDGET_CLASS, key_press_event, (widget, event));
+	result = GTK_WIDGET_CLASS (nautilus_entry_parent_class)->key_press_event (widget, event);
 
 	/* Pressing a key usually changes the selection if there is a selection.
 	 * If there is not selection, we can save work by not emitting a signal.
@@ -163,16 +160,13 @@ nautilus_entry_motion_notify (GtkWidget *widget, GdkEventMotion *event)
 	int result;
 	gboolean old_had, new_had;
 	int old_start, old_end, new_start, new_end;
-	NautilusEntry *entry;
 	GtkEditable *editable;
 
-	entry = NAUTILUS_ENTRY (widget);
 	editable = GTK_EDITABLE (widget);
 
 	old_had = gtk_editable_get_selection_bounds (editable, &old_start, &old_end);
 
-	result = EEL_CALL_PARENT_WITH_RETURN_VALUE
-		(GTK_WIDGET_CLASS, motion_notify_event, (widget, event));
+	result = GTK_WIDGET_CLASS (nautilus_entry_parent_class)->motion_notify_event (widget, event);
 
 	/* Send a signal if dragging the mouse caused the selection to change. */
 	if (result) {
@@ -280,8 +274,7 @@ nautilus_entry_button_press (GtkWidget *widget,
 {
 	gboolean result;
 
-	result = EEL_CALL_PARENT_WITH_RETURN_VALUE
-		(GTK_WIDGET_CLASS, button_press_event, (widget, event));
+	result = GTK_WIDGET_CLASS (nautilus_entry_parent_class)->button_press_event (widget, event);
 
 	if (result) {
 		g_signal_emit (widget, signals[SELECTION_CHANGED], 0);
@@ -296,8 +289,7 @@ nautilus_entry_button_release (GtkWidget *widget,
 {
 	gboolean result;
 
-	result = EEL_CALL_PARENT_WITH_RETURN_VALUE
-		(GTK_WIDGET_CLASS, button_release_event, (widget, event));
+	result = GTK_WIDGET_CLASS (nautilus_entry_parent_class)->button_release_event (widget, event);
 
 	if (result) {
 		g_signal_emit (widget, signals[SELECTION_CHANGED], 0);
@@ -355,16 +347,15 @@ nautilus_entry_selection_clear (GtkWidget *widget,
 {
 	g_assert (NAUTILUS_IS_ENTRY (widget));
 	
-	if (gdk_selection_owner_get (event->selection) == widget->window) {
+	if (gdk_selection_owner_get (event->selection) == gtk_widget_get_window (widget)) {
 		return FALSE;
 	}
 	
-	return EEL_CALL_PARENT_WITH_RETURN_VALUE
-		(GTK_WIDGET_CLASS, selection_clear_event, (widget, event));
+	return GTK_WIDGET_CLASS (nautilus_entry_parent_class)->selection_clear_event (widget, event);
 }
 
 static void
-nautilus_entry_editable_init (GtkEditableClass *iface)
+nautilus_entry_editable_init (GtkEditableInterface *iface)
 {
 	parent_editable_interface = g_type_interface_peek_parent (iface);
 
@@ -382,14 +373,10 @@ static void
 nautilus_entry_class_init (NautilusEntryClass *class)
 {
 	GtkWidgetClass *widget_class;
-	GtkObjectClass *object_class;
 	GObjectClass *gobject_class;
 
-	parent_class = g_type_class_peek_parent (class);
-
 	widget_class = GTK_WIDGET_CLASS (class);
 	gobject_class = G_OBJECT_CLASS (class);
-	object_class = GTK_OBJECT_CLASS (class);
 		
 	widget_class->button_press_event = nautilus_entry_button_press;
 	widget_class->button_release_event = nautilus_entry_button_release;
@@ -402,19 +389,17 @@ nautilus_entry_class_init (NautilusEntryClass *class)
 	/* Set up signals */
 	signals[USER_CHANGED] = g_signal_new
 		("user_changed",
-		 G_TYPE_FROM_CLASS (object_class),
+		 G_TYPE_FROM_CLASS (class),
 		 G_SIGNAL_RUN_LAST,
-		 G_STRUCT_OFFSET (NautilusEntryClass,
-				    user_changed),
+		 G_STRUCT_OFFSET (NautilusEntryClass, user_changed),
 		 NULL, NULL,
 		 g_cclosure_marshal_VOID__VOID,
 		 G_TYPE_NONE, 0);
 	signals[SELECTION_CHANGED] = g_signal_new
 		("selection_changed",
-		 G_TYPE_FROM_CLASS (object_class),
+		 G_TYPE_FROM_CLASS (class),
 		 G_SIGNAL_RUN_LAST,
-		 G_STRUCT_OFFSET (NautilusEntryClass,
-				    selection_changed),
+		 G_STRUCT_OFFSET (NautilusEntryClass, selection_changed),
 		 NULL, NULL,
 		 g_cclosure_marshal_VOID__VOID,
 		 G_TYPE_NONE, 0);
@@ -430,36 +415,3 @@ nautilus_entry_set_special_tab_handling (NautilusEntry *entry,
 }
 
 
-GType
-nautilus_entry_get_type (void)
-{
-	static GType entry_type = 0;
-
-	if (entry_type == 0) {						
-		const GInterfaceInfo editable_info =
-		{
-			(GInterfaceInitFunc) nautilus_entry_editable_init,
-			NULL,
-			NULL
-		};
-
-		const GTypeInfo object_info = {
-		    sizeof (NautilusEntryClass),
-		    NULL,		/* base_init */
-		    NULL,		/* base_finalize */		
-		    (GClassInitFunc) nautilus_entry_class_init,
-		    NULL,		/* class_finalize */		
-		    NULL,               /* class_data */		
-		    sizeof (NautilusEntry),					
-		    0,                  /* n_preallocs */		
-		    (GInstanceInitFunc) nautilus_entry_init
-		};							
-		entry_type = g_type_register_static (
-			GTK_TYPE_ENTRY, "NautilusEntry",
-			&object_info, 0);
-		g_type_add_interface_static (
-			entry_type, GTK_TYPE_EDITABLE, &editable_info);
-	}
-			
-	return entry_type;						
-}
