@@ -39,6 +39,7 @@
 #include "nautilus-icon-private.h"
 #include "nautilus-link.h"
 #include "nautilus-metadata.h"
+#include "nautilus-selection-canvas-item.h"
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gnome-extensions.h>
 #include <eel/eel-graphic-effects.h>
@@ -51,7 +52,7 @@
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <eel/eel-canvas-rect-ellipse.h>
+
 #include <libnautilus-private/nautilus-desktop-background.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-file-changes-queue.h>
@@ -146,7 +147,7 @@ create_selection_shadow (NautilusIconContainer *container,
 		if (x2 >= min_x && x1 <= max_x && y2 >= min_y && y1 <= max_y)
 			eel_canvas_item_new
 				(group,
-				 eel_canvas_rect_get_type (),
+				 NAUTILUS_TYPE_SELECTION_CANVAS_ITEM,
 				 "x1", (double) x1,
 				 "y1", (double) y1,
 				 "x2", (double) x2,
@@ -1363,7 +1364,7 @@ drag_highlight_draw (GtkWidget *widget,
 	style = gtk_widget_get_style_context (widget);
 
 	gtk_style_context_save (style);
-	gtk_style_context_add_class (style, "dnd");
+	gtk_style_context_add_class (style, GTK_STYLE_CLASS_DND);
 	gtk_style_context_set_state (style, GTK_STATE_FLAG_FOCUSED);
 
 	gtk_render_frame (style,
@@ -1372,11 +1373,6 @@ drag_highlight_draw (GtkWidget *widget,
 
 	gtk_style_context_restore (style);
 
-	cairo_set_line_width (cr, 1.0);
-	cairo_set_source_rgb (cr, 0, 0, 0);
-	cairo_rectangle (cr, 0.5, 0.5, width - 1, height - 1);
-	cairo_stroke (cr);
-
 	return FALSE;
 }
 
