@@ -27,6 +27,8 @@
 #include <string.h>
 #include <gio/gio.h>
 
+#include <libtracker-sparql/tracker-sparql.h>
+
 /* If defined, we use fts:match, this has to be enabled in Tracker to
  * work which it usually is. The alternative is to undefine it and
  * use filename matching instead. This doesn't use the content of the
@@ -34,114 +36,14 @@
  */
 #undef FTS_MATCHING
 
-#define MODULE_FILENAME "libtracker-sparql-0.10.so.0"
-
-#define MODULE_MAP(a)   { #a, (gpointer *)&a }
-
-/* Connection object */
-typedef struct _TrackerSparqlConnection TrackerSparqlConnection;
-
-#define TRACKER_SPARQL_TYPE_CONNECTION (tracker_sparql_connection_get_type ())
-#define TRACKER_SPARQL_CONNECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TRACKER_SPARQL_TYPE_CONNECTION, TrackerSparqlConnection))
-
-/* Cursor object */
-typedef struct _TrackerSparqlCursor TrackerSparqlCursor;
-
-#define TRACKER_SPARQL_TYPE_CURSOR (tracker_sparql_cursor_get_type ())
-#define TRACKER_SPARQL_CURSOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TRACKER_SPARQL_TYPE_CURSOR, TrackerSparqlCursor))
-
-/* API */
-static GType                     (*tracker_sparql_connection_get_type)     (void) = NULL;
-static TrackerSparqlConnection * (*tracker_sparql_connection_get)          (GCancellable             *cancellable,
-                                                                            GError                  **error) = NULL;
-static void                      (*tracker_sparql_connection_query_async)  (TrackerSparqlConnection  *self,
-                                                                            const gchar              *sparql,
-                                                                            GCancellable             *cancellable,
-                                                                            GAsyncReadyCallback       callback,
-                                                                            gpointer                  user_data) = NULL;
-static TrackerSparqlCursor *     (*tracker_sparql_connection_query_finish) (TrackerSparqlConnection  *self,
-                                                                            GAsyncResult             *_res_,
-                                                                            GError                  **error) = NULL;
-static GType                     (*tracker_sparql_cursor_get_type)         (void) = NULL;
-static void                      (*tracker_sparql_cursor_next_async)       (TrackerSparqlCursor      *self,
-                                                                            GCancellable             *cancellable,
-                                                                            GAsyncReadyCallback       callback,
-                                                                            gpointer                  user_data) = NULL;
-static gboolean                  (*tracker_sparql_cursor_next_finish)      (TrackerSparqlCursor      *self,
-                                                                            GAsyncResult             *_res_,
-                                                                            GError                  **error) = NULL;
-static const gchar *             (*tracker_sparql_cursor_get_string)       (TrackerSparqlCursor      *self,
-                                                                            gint                     *column,
-                                                                            glong                    *length) = NULL;
-static gchar *                   (*tracker_sparql_escape_string)           (const gchar              *literal) = NULL;
-
-static struct TrackerFunctions
-{
-	const char *name;
-	gpointer *pointer;
-} funcs[] = {
-	MODULE_MAP (tracker_sparql_connection_get_type),
-	MODULE_MAP (tracker_sparql_connection_get),
-	MODULE_MAP (tracker_sparql_connection_query_async),
-	MODULE_MAP (tracker_sparql_connection_query_finish),
-	MODULE_MAP (tracker_sparql_cursor_get_type),
-	MODULE_MAP (tracker_sparql_cursor_next_async),
-	MODULE_MAP (tracker_sparql_cursor_next_finish),
-	MODULE_MAP (tracker_sparql_cursor_get_string),
-	MODULE_MAP (tracker_sparql_escape_string)
-};
-
-static gboolean
-init (void)
-{
-	static gboolean inited = FALSE;
-	gint i;
-	GModule *m;
-	GModuleFlags flags;
-
-	if (inited) {
-		return TRUE;
-	}
-
-	flags = G_MODULE_BIND_LAZY | G_MODULE_BIND_LOCAL;
-
-	/* Only support 0.10 onwards */
-	if ((m = g_module_open (MODULE_FILENAME, flags)) == NULL)  {
-		g_debug ("No tracker backend available or it is not new enough");
-		g_debug ("Only available using '%s'", MODULE_FILENAME);
-		return FALSE;
-	}
-
-	inited = TRUE;
-
-	/* Check for the symbols we need */
-	for (i = 0; i < G_N_ELEMENTS (funcs); i++) {
-		if (!g_module_symbol (m, funcs[i].name, funcs[i].pointer)) {
-			g_warning ("Missing symbol '%s' in libtracker-sparql\n",
-				   funcs[i].name);
-			g_module_close (m);
-
-			for (i = 0; i < G_N_ELEMENTS (funcs); i++)
-				funcs[i].pointer = NULL;
-
-			return FALSE;
-		}
-	}
-
-	g_debug ("Loaded Tracker library and all required symbols");
-
-	return TRUE;
-}
-
 struct NautilusSearchEngineTrackerDetails {
 	TrackerSparqlConnection *connection;
-	GCancellable *cancellable;
+	NautilusQuery *query;
 
-	NautilusQuery 	*query;
-	gboolean 	query_pending;
+	gboolean       query_pending;
+	GCancellable  *cancellable;
 };
 
-
 G_DEFINE_TYPE (NautilusSearchEngineTracker,
 	       nautilus_search_engine_tracker,
 	       NAUTILUS_TYPE_SEARCH_ENGINE);
@@ -208,22 +110,18 @@ cursor_callback (GObject      *object,
 	success = tracker_sparql_cursor_next_finish (cursor, result, &error);
 
 	if (error) {
+		tracker->details->query_pending = FALSE;
 		nautilus_search_engine_error (NAUTILUS_SEARCH_ENGINE (tracker), error->message);
 		g_error_free (error);
-
-		if (cursor) {
-			g_object_unref (cursor);
-		}
+		g_object_unref (cursor);
 
 		return;
 	}
 
 	if (!success) {
+		tracker->details->query_pending = FALSE;
 		nautilus_search_engine_finished (NAUTILUS_SEARCH_ENGINE (tracker));
-
-		if (cursor) {
-			g_object_unref (cursor);
-		}
+		g_object_unref (cursor);
 
 		return;
 	}
@@ -249,20 +147,20 @@ query_callback (GObject      *object,
 
 	tracker = NAUTILUS_SEARCH_ENGINE_TRACKER (user_data);
 
-	tracker->details->query_pending = FALSE;
-
 	connection = TRACKER_SPARQL_CONNECTION (object);
 	cursor = tracker_sparql_connection_query_finish (connection,
 	                                                 result,
 	                                                 &error);
 
 	if (error) {
+		tracker->details->query_pending = FALSE;
 		nautilus_search_engine_error (NAUTILUS_SEARCH_ENGINE (tracker), error->message);
 		g_error_free (error);
 		return;
 	}
 
 	if (!cursor) {
+		tracker->details->query_pending = FALSE;
 		nautilus_search_engine_finished (NAUTILUS_SEARCH_ENGINE (tracker));
 		return;
 	}
@@ -289,6 +187,8 @@ nautilus_search_engine_tracker_start (NautilusSearchEngine *engine)
 		return;
 	}
 
+	g_cancellable_reset (tracker->details->cancellable);
+
 	search_text = nautilus_query_get_text (tracker->details->query);
 	location_uri = nautilus_query_get_location (tracker->details->query);
 	mimetypes = nautilus_query_get_mime_types (tracker->details->query);
@@ -356,6 +256,12 @@ nautilus_search_engine_tracker_start (NautilusSearchEngine *engine)
 
 	g_string_append (sparql, ")");
 
+	if (location_uri)  {
+		g_string_append (sparql, " && fn:starts-with(nie:url(?urn),");
+		sparql_append_string_literal (sparql, location_uri);
+		g_string_append (sparql, ")");
+	}
+
 	if (mime_count > 0) {
 		g_string_append (sparql, " && ");
 		g_string_append (sparql, "(");
@@ -407,12 +313,6 @@ nautilus_search_engine_tracker_stop (NautilusSearchEngine *engine)
 	}
 }
 
-static gboolean
-nautilus_search_engine_tracker_is_indexed (NautilusSearchEngine *engine)
-{
-	return TRUE;
-}
-
 static void
 nautilus_search_engine_tracker_set_query (NautilusSearchEngine *engine, NautilusQuery *query)
 {
@@ -444,7 +344,6 @@ nautilus_search_engine_tracker_class_init (NautilusSearchEngineTrackerClass *cla
 	engine_class->set_query = nautilus_search_engine_tracker_set_query;
 	engine_class->start = nautilus_search_engine_tracker_start;
 	engine_class->stop = nautilus_search_engine_tracker_stop;
-	engine_class->is_indexed = nautilus_search_engine_tracker_is_indexed;
 
 	g_type_class_add_private (class, sizeof (NautilusSearchEngineTrackerDetails));
 }
@@ -461,35 +360,20 @@ NautilusSearchEngine *
 nautilus_search_engine_tracker_new (void)
 {
 	NautilusSearchEngineTracker *engine;
-	GCancellable *cancellable;
 	TrackerSparqlConnection *connection;
 	GError *error = NULL;
 
-	if (!init()) {
-		return NULL;
-	}
-
-	cancellable = g_cancellable_new ();
-	connection = tracker_sparql_connection_get (cancellable, &error);
+	connection = tracker_sparql_connection_get (NULL, &error);
 
 	if (error) {
 		g_warning ("Could not establish a connection to Tracker: %s", error->message);
 		g_error_free (error);
-		g_object_unref (cancellable);
-
-		return NULL;
-	} else if (!connection) {
-		g_warning ("Could not establish a connection to Tracker, no TrackerSparqlConnection was returned");
-		g_object_unref (cancellable);
-
 		return NULL;
 	}
 
 	engine = g_object_new (NAUTILUS_TYPE_SEARCH_ENGINE_TRACKER, NULL);
-
 	engine->details->connection = connection;
-	engine->details->cancellable = cancellable;	
-	engine->details->query_pending = FALSE;
+	engine->details->cancellable = g_cancellable_new ();
 
 	return NAUTILUS_SEARCH_ENGINE (engine);
 }
