@@ -24,7 +24,10 @@
 #include <config.h>
 #include "nautilus-search-engine.h"
 #include "nautilus-search-engine-simple.h"
+
+#ifdef ENABLE_TRACKER
 #include "nautilus-search-engine-tracker.h"
+#endif
 
 #include <eel/eel-gtk-macros.h>
 
@@ -125,10 +128,12 @@ nautilus_search_engine_new (void)
 {
 	NautilusSearchEngine *engine;
 	
+#ifdef ENABLE_TRACKER	
 	engine = nautilus_search_engine_tracker_new ();
 	if (engine) {
 		return engine;
 	}
+#endif
 	
 	engine = nautilus_search_engine_simple_new ();
 	return engine;
@@ -162,15 +167,6 @@ nautilus_search_engine_stop (NautilusSearchEngine *engine)
 	NAUTILUS_SEARCH_ENGINE_GET_CLASS (engine)->stop (engine);
 }
 
-gboolean
-nautilus_search_engine_is_indexed (NautilusSearchEngine *engine)
-{
-	g_return_val_if_fail (NAUTILUS_IS_SEARCH_ENGINE (engine), FALSE);
-	g_return_val_if_fail (NAUTILUS_SEARCH_ENGINE_GET_CLASS (engine)->is_indexed != NULL, FALSE);
-
-	return NAUTILUS_SEARCH_ENGINE_GET_CLASS (engine)->is_indexed (engine);
-}
-
 void	       
 nautilus_search_engine_hits_added (NautilusSearchEngine *engine, GList *hits)
 {
