@@ -494,11 +494,10 @@ nautilus_window_slot_open_location_full (NautilusWindowSlot *slot,
 	if (use_same) {
 		target_window = window;
 	} else {
-		app = nautilus_application_dup_singleton ();
+		app = nautilus_application_get_singleton ();
 		target_window = nautilus_application_create_window
 			(app,
 			 gtk_window_get_screen (GTK_WINDOW (window)));
-		g_object_unref (app);
 	}
 
         g_assert (target_window != NULL);
@@ -713,11 +712,13 @@ begin_location_change (NautilusWindowSlot *slot,
 			from_folder = parent;
 			parent = g_file_get_parent (from_folder);
 		}
+
 		if (parent != NULL) {
 			new_selection = g_list_prepend (NULL, nautilus_file_get (from_folder));
+			g_object_unref (parent);
 		}
+
 		g_object_unref (from_folder);
-		g_object_unref (parent);
 	}
 
 	end_location_change (slot);
@@ -846,6 +847,7 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 	GFile *location;
 	GMountOperation *mount_op;
 	MountNotMountedData *data;
+	NautilusApplication *app;
 
 	slot = callback_data;
 	g_assert (NAUTILUS_IS_WINDOW_SLOT (slot));
@@ -889,10 +891,12 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 		}
 
 		g_clear_object (&slot->pending_location);
+		g_free (slot->pending_scroll_to);
 	
 		slot->pending_location = nautilus_file_get_parent_location (file);
 		slot->pending_selection = g_list_prepend (NULL, nautilus_file_ref (file));
 		slot->determine_view_file = nautilus_file_get_parent (file);
+		slot->pending_scroll_to = nautilus_file_get_uri (file);
 
 		nautilus_file_invalidate_all_attributes (slot->determine_view_file);
 		nautilus_file_call_when_ready (slot->determine_view_file,
@@ -964,9 +968,7 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 			 */
 			/* if this is the only window, we don't want to quit, so we redirect it to home */
 
-			NautilusApplication *app;
-
-			app = nautilus_application_dup_singleton ();
+			app = nautilus_application_get_singleton ();
 			
 			if (g_list_length (gtk_application_get_windows (GTK_APPLICATION (app))) == 1) {
 				/* the user could have typed in a home directory that doesn't exist,
@@ -991,8 +993,6 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 				/* Since this is a window, destroying it will also unref it. */
 				gtk_widget_destroy (GTK_WIDGET (window));
 			}
-
-			g_object_unref (app);
 		} else {
 			/* Clean up state of already-showing window */
 			end_location_change (slot);
@@ -1231,6 +1231,8 @@ real_setup_loading_floating_bar (NautilusWindowSlot *slot)
 	nautilus_floating_bar_add_action (NAUTILUS_FLOATING_BAR (slot->floating_bar),
 					  GTK_STOCK_STOP,
 					  NAUTILUS_FLOATING_BAR_ACTION_ID_STOP);
+
+	gtk_widget_set_halign (slot->floating_bar, GTK_ALIGN_END);
 	gtk_widget_show (slot->floating_bar);
 }
 
