@@ -72,8 +72,6 @@
 #include <math.h>
 #include <sys/time.h>
 
-#define MAX_HISTORY_ITEMS 50
-
 #define SIDE_PANE_MINIMUM_WIDTH 1
 #define SIDE_PANE_MINIMUM_HEIGHT 400
 
@@ -143,7 +141,6 @@ static const struct {
 	{ XF86XK_AddFavorite,	NAUTILUS_ACTION_ADD_BOOKMARK },
 	{ XF86XK_Favorites,	NAUTILUS_ACTION_EDIT_BOOKMARKS },
 	{ XF86XK_Go,		NAUTILUS_ACTION_GO_TO_LOCATION },
-/* TODO?{ XF86XK_History,	NAUTILUS_ACTION_HISTORY }, */
 	{ XF86XK_HomePage,      NAUTILUS_ACTION_GO_HOME },
 	{ XF86XK_OpenURL,	NAUTILUS_ACTION_GO_TO_LOCATION },
 	{ XF86XK_Refresh,	NAUTILUS_ACTION_RELOAD },
@@ -862,11 +859,7 @@ nautilus_window_save_geometry (NautilusWindow *window)
 void
 nautilus_window_close (NautilusWindow *window)
 {
-	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
-
-	nautilus_window_save_geometry (window);
-
-	gtk_widget_destroy (GTK_WIDGET (window));
+	NAUTILUS_WINDOW_CLASS (G_OBJECT_GET_CLASS (window))->close (window);
 }
 
 NautilusWindowSlot *
@@ -1098,26 +1091,25 @@ static gboolean
 nautilus_window_key_press_event (GtkWidget *widget,
 				 GdkEventKey *event)
 {
-	static gpointer grand_parent_class = NULL;
 	NautilusWindow *window;
+	NautilusWindowSlot *active_slot;
+	NautilusView *view;
 	int i;
-	gboolean handled;
 
 	window = NAUTILUS_WINDOW (widget);
-	handled = FALSE;
 
-	if (!grand_parent_class) {
-		grand_parent_class = g_type_class_peek_parent (nautilus_window_parent_class);
-	}
+	active_slot = nautilus_window_get_active_slot (window);
+	view = active_slot->content_view;
 
-	/* See https://bugzilla.gnome.org/show_bug.cgi?id=314431
-	 *
-	 * We need to handle the keybindings for the currently focused widget
-	 * before the common accelerator bindings.
-	 */
-	handled = gtk_window_propagate_key_event (GTK_WINDOW (window), event);
-	if (handled) {
-		return TRUE;
+	if (view != NULL && nautilus_view_get_is_renaming (view)) {
+		/* if we're renaming, just forward the event to the
+		 * focused widget and return. We don't want to process the window
+		 * accelerator bindings, as they might conflict with the 
+		 * editable widget bindings.
+		 */
+		if (gtk_window_propagate_key_event (GTK_WINDOW (window), event)) {
+			return TRUE;
+		}
 	}
 
 	for (i = 0; i < G_N_ELEMENTS (extra_window_keybindings); i++) {
@@ -1136,22 +1128,14 @@ nautilus_window_key_press_event (GtkWidget *widget,
 			g_assert (action != NULL);
 			if (gtk_action_is_sensitive (action)) {
 				gtk_action_activate (action);
-				handled = TRUE;
+				return TRUE;
 			}
 
 			break;
 		}
 	}
 
-	if (!handled) {
-		handled  = gtk_window_activate_key (GTK_WINDOW (window), event);
-	}
-
-	if (!handled) {
-		handled = GTK_WIDGET_CLASS (grand_parent_class)->key_press_event (widget, event);
-	}
-
-	return handled;
+	return GTK_WIDGET_CLASS (nautilus_window_parent_class)->key_press_event (widget, event);
 }
 
 /*
@@ -1759,42 +1743,6 @@ nautilus_window_get_slot_for_view (NautilusWindow *window,
 	return NULL;
 }
 
-void
-nautilus_forget_history (void) 
-{
-	NautilusWindowSlot *slot;
-	GList *window_node, *l, *walk;
-	NautilusApplication *app;
-
-	app = nautilus_application_get_singleton ();
-
-	/* Clear out each window's back & forward lists. Also, remove 
-	 * each window's current location bookmark from history list 
-	 * so it doesn't get clobbered.
-	 */
-	for (window_node = gtk_application_get_windows (GTK_APPLICATION (app));
-	     window_node != NULL;
-	     window_node = window_node->next) {
-
-		NautilusWindow *window;
-			
-		window = window_node->data;
-
-		for (walk = window->details->panes; walk; walk = walk->next) {
-			NautilusWindowPane *pane = walk->data;
-			for (l = pane->slots; l != NULL; l = l->next) {
-				slot = l->data;
-
-				nautilus_window_slot_clear_back_list (slot);
-				nautilus_window_slot_clear_forward_list (slot);
-			}
-		}
-
-		nautilus_window_allow_back (window, FALSE);
-		nautilus_window_allow_forward (window, FALSE);
-	}
-}
-
 NautilusWindowType
 nautilus_window_get_window_type (NautilusWindow *window)
 {
@@ -2055,6 +2003,16 @@ real_get_icon (NautilusWindow *window,
 				       NAUTILUS_FILE_ICON_FLAGS_USE_MOUNT_ICON);
 }
 
+static void
+real_window_close (NautilusWindow *window)
+{
+	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
+
+	nautilus_window_save_geometry (window);
+
+	gtk_widget_destroy (GTK_WIDGET (window));
+}
+
 static void
 nautilus_window_class_init (NautilusWindowClass *class)
 {
@@ -2079,6 +2037,7 @@ nautilus_window_class_init (NautilusWindowClass *class)
 	class->window_type = NAUTILUS_WINDOW_NAVIGATION;
 	class->bookmarks_placeholder = MENU_PATH_BOOKMARKS_PLACEHOLDER;
 	class->get_icon = real_get_icon;
+	class->close = real_window_close;
 
 	properties[PROP_DISABLE_CHROME] =
 		g_param_spec_boolean ("disable-chrome",
